% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pca.fa.owa.R
\name{pca.fa.owa}
\alias{pca.fa.owa}
\title{self-X autonomic unsupervised feature selection}
\usage{
pca.fa.owa(dataDF)
}
\arguments{
\item{dataDF}{dataframe containing clean data (no outliers,
no missing values, no constant values) for data mining activities.
ONLY numerical input variables allowed (that it can be normalized or not).}
}
\value{
text string with the names of the selected variables
}
\description{
With the aim of making UNSUPERVISED feature selection more autonomic,
an ad-hoc procedure is implemented here following next approach:
\enumerate{
\item Initially, well-known techniques as PCA and FA are used
to select the most important features under different criteria.
\item Subsequently, an OWA operator is applied to to determine which
 3 variables are the most relevant to be used as input in the following
 clustering phase
}
}
\details{
The feature selection process applied to the data is as follows:
\itemize{
\item Missing values are treated (assigned to zero).
\item The data is normalized (Z-Score standarization).
\item Different unsupervised feature selection techniques are applied to the data
  to establish different importance values of the variables considered.

  Specifically 4 methods:

   \itemize{
    \item Evaluation with PCA. 3 variants of the method are applied:
     \itemize{
       \item (1) PCA on the first principal component.
       \item (2) PCA on all those principal components that are above the mean eigenvalues.
       \item (3) PCA on all principal components that contain 90\% of the explained variance.
     }
    In all cases, the importance value of the variable is assigned based on the
    sum of the loadings of the selected principal components, normalized by the
    total sum of all loadings.

    \item Evaluation with FA. 1 variant of the method is applied:
        \itemize{
        \item (4) FA on all factors. To determine the number of factors, Horn's
        Parallel Analysis is applied. A Maximum Neighborhood factorization
        and Varimax rotation are used.
        }
    In all cases, the importance value of the variable is assigned based on
    the \emph{communality} value of the variable, normalized by the sum of all
    \emph{communalities}.
    }
\item Based on the evaluation obtained, a multi-criteria decision-making
  process is carried out based on:
    \itemize{
       OWA (Ordered Weighted Averaging) operator: applying the RIM (Regular
       Increasing Monotone) quantifier \eqn{\alpha(r)=r^{\alpha}},
       \eqn{r\geq 0} with \eqn{orness=0.4} on the evaluations, an importance is
       established for each characteristic, selecting in each case only
       the most important ones.
    }
\item A subset of features is selected and returned.
}
}
\note{
The s-X-AIPI project has received funding from the European Union's Horizon
Europe research and innovation programme under grant agreement Nº 101058715
\url{https://s-x-aipi-project.eu/}
}
\examples{
## load dataset
data(mtcars)
## run pca.fa.owa method
pca.fa.owa(mtcars)
}
\references{
A. Malhi. "PCA-based feautre selection scheme for machine defect classification"
IEEE Transactions on Instrumentation and Measurement, 35(6):1517–1525, 2004.

K. Z. Mao. "Identifying critical variables of principal components for
unsupervised feature selection" IEEE Transaction on System, Man
and Cybernetics, 35(2):339–344, 2005.

W.J. Krzanowski and F.H.C Marriott. Multivariate analysis (2 vols).
Edward Arnold, 1994.

R.R. Yager. "On ordered weighted averaging aggregation operators in
multi-criteria decision making" IEEE Transactions on Systems, Man
and Cybernetics, 18:183–190, 1998.

M. Galende-Hernández, M. Menéndez, M.J. Fuente, G.I. Sainz-Palmero
"Monitor-While-Drilling-based estimation of rock mass rating with
computational intelligence: The case of tunnel excavation front"
Automation in Construction, 93:325-338, 2018.
}
\seealso{
\code{\link[stats:prcomp]{prcomp}} for PCA, \code{\link[psych:fa.parallel]{fa.parallel}} for FA and \code{\link[agop:owa]{owa}} for OWA.
}
\keyword{autonomic}
\keyword{feature}
\keyword{package}
\keyword{s-X-AIPI}
\keyword{selection}
\keyword{selfX}
