% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/relief.owa.R
\name{relief.owa}
\alias{relief.owa}
\title{self-X autonomic supervised feature selection}
\usage{
relief.owa(dataDF, varsINPUT, varsOUTPUT)
}
\arguments{
\item{dataDF}{dataframe containing clean data (no outliers,
no missing values, no constant values) for data mining activities.
ONLY numerical input variables allowed (that it can be normalized or not).}

\item{varsINPUT}{vector with the names of the input variables.}

\item{varsOUTPUT}{vector with the name of the output variable. Only one output variable is allowed.}
}
\value{
text string with the names of the selected input variables
}
\description{
With the aim of making SUPERVISED feature selection more autonomic,
an ad-hoc procedure is implemented here following next approach:
\enumerate{
\item Initially, well-known technique as RELIEF is used
to select the most important features under different criteria.
\item Subsequently, an OWA operator is applied to to determine which
 3 variables are the most relevant to be used as input in the following
 modelling phase
}
}
\details{
The feature selection process applied to the data is as follows:
\itemize{
\item The available data sets are randomly divided into 5 training
and test datasets to have a 5-fold cross-validation process.
\item Different supervised feature selection techniques are applied to the data
  to establish different importance values of the variables considered. First
  an evaluator filter method based on RELIEF is used and then 6 different
  direct search algorithms (cutt-off method) are applied using a 5-fold
  cross validation approach:
   \enumerate{
    \item  (1) Select K best
    \item  (2) Select Percentile
    \item  (3) Select threshold
    \item  (4) Select threshold range
    \item  (5) Select difference
    \item  (6) Select slope
    }
    In all cases, the importance value of the variable is assigned based on
    the number of times it has been selected.
\item Based on the evaluation obtained, a multi-criteria decision-making
  process is carried out based on:
    \itemize{
       \item OWA (Ordered Weighted Averaging) operator: applying the RIM (Regular
       Increasing Monotone) quantifier \eqn{\alpha(r)=r^{\alpha}},
       \eqn{r\geq 0} with \eqn{orness=0.4} on the evaluations, an importance is
       established for each characteristic, selecting in each case only
       the most important ones.
    }
\item A subset of features is selected and returned.
}
}
\note{
The s-X-AIPI project has received funding from the European Union's Horizon
Europe research and innovation programme under grant agreement Nº 101058715
\url{https://s-x-aipi-project.eu/}
}
\examples{
\dontshow{if (FALSE) (if (getRversion() >= "3.4") withAutoprint else force)(\{ # examplesIf}
## load dataset
data(mtcars)
## establish inputs and output
varsINPUT <- c("mpg","cyl","disp","hp","drat","wt","qsec","vs","am","gear")
varsOUTPUT <- c("carb")
## run relief.owa method
relief.owa(mtcars,varsINPUT,varsOUTPUT)
\dontshow{\}) # examplesIf}
}
\references{
Kenji Kira and Larry A. Rendell. "A practical approach to feature selection"
In Machine Learning Proceedings 1992, pages 249-256. Elsevier, 1992.

R.R. Yager. "On ordered weighted averaging aggregation operators in
multi-criteria decision making" IEEE Transactions on Systems, Man
and Cybernetics, 18:183–190, 1998.

F. Aragón-Royón, A. Jiménez-Vílchez, A. Arauzo-Azofra, J.M. Benitez "FSinR:
an exhaustive package for feature selection" arXiv e-prints, 2020.
}
\seealso{
\href{https://dicits.ugr.es/software/FSinR/#fsinr-package}{FSinR}
for RELIEF methods and \code{\link[agop:owa]{owa}} for OWA.
}
\keyword{autonomic}
\keyword{feature}
\keyword{package}
\keyword{s-X-AIPI}
\keyword{selection}
\keyword{selfX}
